/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.runtime.assembler;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;
import org.sonatype.plexus.template.Templater;
import org.sonatype.plexus.template.loader.FileTemplateLoader;
import org.sonatype.runtime.descriptor.AssembliesDescriptor;
import org.sonatype.runtime.descriptor.AssemblyDescriptor;

/**
 * JAVADOC
 *
 * @author Alin Dreghiciu
 */
public class Assemblies
{

    private final Collection<Assembly> assemblies;

    Assemblies( final AssembliesDescriptor descriptor,
                final ArtifactResolver resolver,
                final Templater templater )
        throws Exception
    {        
        templater.setTemplateLoader( new FileTemplateLoader() );

        this.assemblies = new ArrayList<Assembly>();

        if ( descriptor.getAssemblies() != null )
        {
            for ( AssemblyDescriptor assemblyDescriptor : descriptor.getAssemblies() )
            {
                assemblies.add( new Assembly( assemblyDescriptor, resolver, templater ) );
            }
        }
    }

    public void build( final Map<String, String> envProperties,
                       final File targetDir )
        throws Exception
    {
        for ( Assembly assembly : assemblies )
        {
            assembly.build( envProperties, targetDir );
        }
    }

}