/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.runtime.assembler;

/**
 * JAVADOC
 *
 * @author Alin Dreghiciu
 */
class AssemblyProperty
{

    private final String name;
    private final String[] values;
    private final boolean collection;

    private final MergePolicy mergePolicy;

    public AssemblyProperty( final String name,
                             final String value,
                             final MergePolicy mergePolicy )
    {
        this.name = name;
        this.values = new String[]{ value };
        this.collection = false;
        this.mergePolicy = mergePolicy;
    }

    public AssemblyProperty( final String name,
                             final String[] values,
                             final MergePolicy mergePolicy )
    {
        this.name = name;
        this.values = values == null ? new String[0] : values;
        this.collection = true;
        this.mergePolicy = mergePolicy;
    }

    public String getName()
    {
        return name;
    }

    public String[] getValues()
    {
        return values;
    }

    public boolean isCollection()
    {
        return collection;
    }

    public MergePolicy getMergePolicy()
    {
        return mergePolicy;
    }

    @Override
    public boolean equals( final Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( !( o instanceof AssemblyProperty ) )
        {
            return false;
        }

        final AssemblyProperty property = (AssemblyProperty) o;

        if ( !name.equals( property.name ) )
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        return name.hashCode();
    }
}
