/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.runtime.assembler;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import org.codehaus.plexus.util.FileUtils;
import org.sonatype.plexus.template.Templater;

/**
 * JAVADOC
 *
 * @author Alin Dreghiciu
 */
public class VirtualArchive
    extends Archive
{

    VirtualArchive( final File archiveDir,
                    final Templater templater,
                    final String outputDirectory )
        throws Exception
    {
        super( createVirtualArchiveDir( archiveDir, outputDirectory ), templater );
    }

    private static File createVirtualArchiveDir( final File archiveDir,
                                                 final String outputDirectory )
        throws IOException
    {
        final File virtualDir = new File( archiveDir.getParent(), archiveDir.getName() + "-virtual" );

        final File outputDir = new File( new File( virtualDir, "data" ), outputDirectory );
        outputDir.mkdirs();

        FileUtils.copyDirectoryStructure( archiveDir, outputDir );

        final File metadataDir = new File( virtualDir, "metadata" );
        metadataDir.mkdirs();

        final FileWriter writer = new FileWriter( new File( metadataDir, "metadata.xml" ) );
        writer.write( "<metadata></metadata>" );
        writer.flush();
        writer.close();

        return virtualDir;
    }

}
